@@ -1,5 +1,4 @@
 import logging
-from typing import Optional
 
 from vortex.Tuple import Tuple
 from vortex.rpc.RPC import vortexRPC
@@ -14,7 +13,14 @@ from peek_core_search._private.storage.EncodedSearchIndexChunk import (
 from peek_core_search._private.storage.EncodedSearchObjectChunk import (
     EncodedSearchObjectChunk,
 )
-from peek_plugin_base.PeekVortexUtil import peekServerName, peekBackendNames
+from peek_core_search._private.tuples.search_index.SearchIndexUpdateDateTuple import (
+    SearchIndexUpdateDateTuple,
+)
+from peek_core_search._private.tuples.search_object.SearchObjectUpdateDateTuple import (
+    SearchObjectUpdateDateTuple,
+)
+from peek_plugin_base.PeekVortexUtil import peekBackendNames
+from peek_plugin_base.PeekVortexUtil import peekServerName
 
 logger = logging.getLogger(__name__)
 
@@ -30,7 +36,9 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         """
 
         yield self.loadSearchIndexChunks.start(funcSelf=self)
+        yield self.loadSearchIndexDelta.start(funcSelf=self)
         yield self.loadSearchObjectChunks.start(funcSelf=self)
+        yield self.loadSearchObjectDelta.start(funcSelf=self)
         logger.debug("RPCs started")
 
     # -------------
@@ -41,14 +49,11 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         additionalFilt=searchFilt,
         deferToThread=True,
     )
-    def loadSearchIndexChunks(self, offset: int, count: int) -> str:
-        """Update Page Loader Status
-
-        Tell the server of the latest status of the loader
-
-        """
-        return self.ckiInitialLoadChunksPayloadBlocking(
-            offset, count, EncodedSearchIndexChunk
+    def loadSearchIndexDelta(self, indexEncodedPayload: bytes) -> bytes:
+        return self.ckiChunkIndexDeltaBlocking(
+            indexEncodedPayload,
+            EncodedSearchIndexChunk,
+            SearchIndexUpdateDateTuple,
         )
 
     # -------------
@@ -59,12 +64,35 @@ class ClientChunkLoadRpc(ACIChunkLoadRpcABC):
         additionalFilt=searchFilt,
         deferToThread=True,
     )
-    def loadSearchObjectChunks(self, offset: int, count: int) -> list[Tuple]:
-        """Update Page Loader Status
-
-        Tell the server of the latest status of the loader
-
-        """
+    def loadSearchIndexChunks(self, chunkKeys: list[str]) -> list[Tuple]:
         return self.ckiInitialLoadChunksPayloadBlocking(
-            offset, count, EncodedSearchObjectChunk
+            chunkKeys, EncodedSearchIndexChunk
+        )
+
+    # -------------
+    @vortexRPC(
+        peekServerName,
+        acceptOnlyFromVortex=peekBackendNames,
+        timeoutSeconds=60,
+        additionalFilt=searchFilt,
+        deferToThread=True,
+    )
+    def loadSearchObjectDelta(self, indexEncodedPayload: bytes) -> bytes:
+        return self.ckiChunkIndexDeltaBlocking(
+            indexEncodedPayload,
+            EncodedSearchObjectChunk,
+            SearchObjectUpdateDateTuple,
+        )
+
+    # -------------
+    @vortexRPC(
+        peekServerName,
+        acceptOnlyFromVortex=peekBackendNames,
+        timeoutSeconds=60,
+        additionalFilt=searchFilt,
+        deferToThread=True,
+    )
+    def loadSearchObjectChunks(self, chunkKeys: list[str]) -> list[Tuple]:
+        return self.ckiInitialLoadChunksPayloadBlocking(
+            chunkKeys, EncodedSearchObjectChunk
         )
