@@ -28,3 +28,13 @@ class SearchIndexUpdateDateTuple(Tuple, ACIUpdateDateTupleABC):
     @property
     def ckiUpdateDateByChunkKey(self):
         return self.updateDateByChunkKey
+
+    def ckiSetUpdateDateByChunkKey(self, value: Dict[str, str]) -> None:
+        self.updateDateByChunkKey = value
+
+    @property
+    def ckiInitialLoadComplete(self) -> bool:
+        return self.initialLoadComplete
+
+    def ckiSetInitialLoadComplete(self, value: bool) -> None:
+        self.initialLoadComplete = value
